@@ -72,6 +72,14 @@ HighsStatus solveLp(HighsLpSolverObject& solver_object, const string message) {
                                           return_status, "solveLpCupdlp");
     }
     if (return_status == HighsStatus::kError) return return_status;
+    // IPM (and PDLP?) can claim optimality with large primal and/or
+    // dual residual errors, so must correct any residual errors that
+    // exceed the tolerance in this scenario.
+    //
+    // OK to correct residual errors whatever the model status, as
+    // it's only changed in the case of optimality
+    correctResiduals(solver_object);
+
     // Non-error return requires a primal solution
     assert(solver_object.solution_.value_valid);
     // Get the objective and any KKT failures
@@ -79,6 +87,10 @@ HighsStatus solveLp(HighsLpSolverObject& solver_object, const string message) {
         solver_object.lp_.objectiveValue(solver_object.solution_.col_value);
     getLpKktFailures(options, solver_object.lp_, solver_object.solution_,
                      solver_object.basis_, solver_object.highs_info_);
+    if (solver_object.model_status_ == HighsModelStatus::kOptimal &&
+        (solver_object.highs_info_.num_primal_infeasibilities > 0 ||
+         solver_object.highs_info_.num_dual_infeasibilities))
+      solver_object.model_status_ = HighsModelStatus::kUnknown;
     if (options.solver == kIpmString || options.run_centring) {
       // Setting the IPM-specific values of (highs_)info_ has been done in
       // solveLpIpx
@@ -127,7 +139,7 @@ HighsStatus solveLp(HighsLpSolverObject& solver_object, const string message) {
             return HighsStatus::kError;
           }
         }  // options.run_crossover == kHighsOnString
-      }    // unwelcome_ipx_status
+      }  // unwelcome_ipx_status
     } else {
       // PDLP has been used, so check whether claim of optimality
       // satisfies the HiGHS criteria
@@ -136,7 +148,7 @@ HighsStatus solveLp(HighsLpSolverObject& solver_object, const string message) {
       // and duality gap that are within the tolerances supplied by
       // HiGHS, the HiGHS primal and dual feasibility tolerances may
       // not be satisfied since they are absolute, and in PDLP they
-      // are relative. Note that, even when only one PDLP row activit
+      // are relative. Note that, even when only one PDLP row activity
       // fails to satisfy the absolute tolerance, the absolute norm
       // measure reported by PDLP will not necessarily be the same as
       // with HiGHS, since PDLP uses the 2-norm, and HiGHS the
