@@ -134,6 +134,11 @@ class HEkk {
   HighsBasis getHighsBasis(HighsLp& use_lp) const;
 
   const SimplexBasis& getSimplexBasis() { return basis_; }
+  double computeBasisCondition(const HighsLp& lp, const bool exact = false,
+                               const bool report = false);
+  double computeBasisCondition() {
+    return computeBasisCondition(this->lp_, false, false);
+  }
 
   HighsStatus initialiseSimplexLpBasisAndFactor(
       const bool only_from_known_basis = false);
@@ -244,6 +249,7 @@ class HEkk {
   double debug_max_relative_dual_steepest_edge_weight_error;
 
   std::vector<HighsSimplexBadBasisChangeRecord> bad_basis_change_;
+  std::vector<double> primal_phase1_dual_;
 
  private:
   bool isUnconstrainedLp();
@@ -332,7 +338,6 @@ class HEkk {
   HighsStatus returnFromEkkSolve(const HighsStatus return_status);
   HighsStatus returnFromSolve(const HighsStatus return_status);
 
-  double computeBasisCondition();
   void initialiseAnalysis();
   std::string rebuildReason(const HighsInt rebuild_reason);
 
